<?php
/**
 * Plugin Name: Stepped Content
 * Description: Seamlessly organize your information into interactive steps.
 * Version: 1.0.1
 * Author: bPlugins
 * Author URI: https://bplugins.com
 * License: GPLv3
 * License URI: https://www.gnu.org/licenses/gpl-3.0.txt
 * Text Domain: stepped-content
 */

// ABS PATH
if ( !defined( 'ABSPATH' ) ) { exit; }

// Constant
define( 'STP_PLUGIN_VERSION', isset( $_SERVER['HTTP_HOST'] ) && 'localhost' === $_SERVER['HTTP_HOST'] ? time() : '1.0.1' );
define( 'STP_DIR_URL', plugin_dir_url( __FILE__ ) );
define( 'STP_DIR_PATH', plugin_dir_path( __FILE__ ) );

// Stepped Content
class STPContent{
	function __construct(){
		add_action( 'init', [$this, 'onInit'] );
	}

	function onInit() {
		wp_register_style( 'stp-content-style', STP_DIR_URL . 'dist/style.css', [], STP_PLUGIN_VERSION ); // Style
		wp_register_style( 'stp-content-editor-style', STP_DIR_URL . 'dist/editor.css', [ 'stp-content-style' ], STP_PLUGIN_VERSION ); // Backend Style

		register_block_type( __DIR__, [
			'editor_style'		=> 'stp-content-editor-style',
			'style'				=> 'stp-content-style',
			'render_callback'	=> [$this, 'render']
		] ); // Register Block

		wp_set_script_translations( 'stp-content-editor-script', 'stepped-content', STP_DIR_PATH . 'languages' );
	}

	function render( $attributes, $content ){
		extract( $attributes );

		wp_set_script_translations( 'stp-content-script', 'stepped-content', STP_DIR_PATH . 'languages' );

		$className = $className ?? '';
		$blockClassName = "wp-block-stp-content $className align$align";

		ob_start(); ?>
		<div class='<?php echo esc_attr( $blockClassName ); ?>' id='stpContent-<?php echo esc_attr( $cId ); ?>' data-props='<?php echo esc_attr( wp_json_encode( [ 'attributes' => $attributes, 'content' => $content ] ) ); ?>'></div>

		<?php return ob_get_clean();
	} // Render
}
new STPContent();

// Require files
require_once STP_DIR_PATH . 'child/child.php';